@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2011, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 
 #define VZ_DIR			PKGCONFDIR "/"
 #define GLOBAL_CFG		VZ_DIR "vz.conf"
+#define OSRELEASE_CFG		VZ_DIR "osrelease.conf"
 #define VPS_CONF_DIR		VZ_DIR "conf/"
 #define LIB_SCRIPTS_DIR		PKGLIBDIR "/scripts/"
 #define DIST_DIR		VZ_DIR "dists"
@@ -29,11 +30,14 @@
 
 #define VZFIFO_FILE		"/.vzfifo"
 
-#define VPS_STOP		LIB_SCRIPTS_DIR "vps-stop"
 #define VPS_NET_ADD		LIB_SCRIPTS_DIR "vps-net_add"
 #define VPS_NET_DEL		LIB_SCRIPTS_DIR "vps-net_del"
+#define VPS_PCI			LIB_SCRIPTS_DIR "vps-pci"
 
-#define envid_t 	unsigned int
+/* User-defined scripts are in VPS_CONF_DIR */
+#define USER_CREATE_SCRIPT	VPS_CONF_DIR "vps.create"
+
+#define envid_t		unsigned int
 #define STR_SIZE	512
 #define PATH_LEN	256
 
@@ -45,7 +49,13 @@
 #define DEL		1
 
 /* Default environment variable PATH */
-#define	ENV_PATH	"PATH=/bin:/sbin:/usr/bin:/usr/sbin:"
+#define DEF_PATH	"/usr/local/sbin:/usr/local/bin:" \
+			"/usr/sbin:/usr/bin:/sbin:/bin"
+#define ENV_PATH	"PATH=" DEF_PATH
+
+/* Defaults for checkpointing */
+#define DEF_DUMPDIR	"/vz/dump"
+#define DEF_DUMPFILE	"Dump.%d"
 
 /* CT states */
 enum {
@@ -82,4 +92,7 @@ typedef enum {
 
 typedef int (* execFn)(void *data);
 
+/* Some kernels use a few IDs close to INT_MAX (2147483647) */
+#define VEID_MAX	2147483644
+
 #endif
